Known issues
=======
![](../../doc/widgets/images/storynavigator_logo_small.png)

Known issues: runtime issues that users might experience (with workarounds if available) and misconceptions about how SN works or what it is supposed to do. The following is a list of known issues as part of working with the Orange3 StoryNavigator Add-on:

**1**

.....


**2**

......

**3**

......

**This list of issues can be further updated in the future.**